﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayerController : MonoBehaviour
{


    // カメラオブジェクト.
    private GameObject camera;

    // 最大移動速度.
    public float maximumSpeed;

    // 最小移動速度.
    public float minimumSpeed;

    // 速度に加算する値.
    private float acceleration;

    // 速度に減算する値.
    private float deceleration;

    // 移動する速度.
    private float moveSpeed;

    // マウス感度.
    private float mouseSensitivity;

    // 子のanimator制御.
    private Animator animator;

    // Use Component.
    [SerializeField]
    Rigidbody   myRigid;
    [SerializeField]
    PhotonView  myPV;
    [SerializeField]
    Camera      myView;

    // Use this for initialization.
	void Start () {

        // Process is not Loading Object by myself
        if (!myPV.isMine){
            // myRigid.isKinematic = true;
            myView.transform.gameObject.SetActive(false);
            Destroy(this);
        }

        // Initialize member status
        InitializeStatus();

    }

    // Update is called once per frame.
    void Update()
    {

        // 平行移動.
        TranslationObject();

        // 回転.
        RotationObject();

    }

    // オブジェクトの平行移動.
    void TranslationObject()
    {

        // カメラ座標取得.
        Vector3 cameraPos = camera.transform.position;

        // 方向ベクトル.
        Vector3 moveVector = Vector3.zero;

        // カメラとオブジェクト位置から方向ベクトル算出.
        moveVector = cameraPos - transform.localPosition;

        // y軸の情報は必要ないので0を入れる.
        moveVector.y = 0.0f;

        // ベクトル正規化.
        moveVector = Vector3.Normalize(moveVector);

        // 前進の処理.
        if (Input.GetKey(KeyCode.W))
        {
            // カメラの向いている方向に進める.
            moveSpeed -= acceleration;

            // 最低値以下にならないようにする.
            if (moveSpeed <= minimumSpeed)
            {
                moveSpeed = minimumSpeed;
            }
        }

        // 後退の処理.
        else if (Input.GetKey(KeyCode.S))
        {
            // カメラの向いている方向と逆に進む.
            moveSpeed += acceleration;

            // 最大値以上にならないようにする.
            if (moveSpeed >= maximumSpeed)
            {
                moveSpeed = maximumSpeed;
            }
        }

        // 何もしていないなら減速.
        else
        {
            moveSpeed *= deceleration;
        }

        // 移動.
        transform.localPosition += moveVector * moveSpeed;

        // アニメーション.
        animator.SetFloat("MoveSpeed", moveSpeed);

    }

    // 回転.
    void RotationObject()
    {

        // マウスの移動量.
        Vector3 position = transform.localPosition;

        // targetの位置のY軸を中心に、回転(自転)する.
        transform.RotateAround(position, Vector3.up, Input.GetAxis("Mouse X") * Time.deltaTime * mouseSensitivity);

    }


    // Use Initialize Status.
    void InitializeStatus()
    {

        // カメラオブジェクト取得.
        camera = GameObject.Find("Main Camera");

        // 最大速度初期化.
        //maximumSpeed = 1.0f;

        // 最低速度初期化.
        //minimumSpeed = -1.0f;

        // 速度に加算する値初期化.
        acceleration = 0.1f;

        // 速度に減算する値初期化.
        deceleration = 0.3f;

        // 移動速度初期化.
        moveSpeed = 0.0f;

        // マウス感度初期化.
        mouseSensitivity = 200f;

        // 子のanimator取得.
        animator = this.gameObject.GetComponentInChildren<Animator>();
    
    }


}
